==> haskell-hls-gadt-plugin-2.1.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-gadt-plugin-2.1.0.0-4VAckkGG7pdCvUN1ka8Rv7
key:                  hls-gadt-plugin-2.1.0.0-4VAckkGG7pdCvUN1ka8Rv7
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  70833aa17f4f92ea68d0b62a11a7aa2c
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.1.0.0-4VAckkGG7pdCvUN1ka8Rv7
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb base-4.17.2.1 containers-0.6.7
    extra-1.7.16-5K8PvZO4Jh1LEHVlaJYF8M ghc-9.4.8 ghc-boot-th-9.4.8
    ghc-exactprint-1.6.1-KoxfBAoehN54yCB9l1b1I2
    ghcide-2.1.0.0-13MzKdzkMl5nB5TLoyXA8
    hls-plugin-api-2.1.0.0-KgqOGj7ddh79pdBAmzh4H2
    hls-refactor-plugin-2.1.0.0-AYE08o2RKoeHUF4Kg1xyFr
    lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-gadt-plugin-2.1.0.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-gadt-plugin-2.1.0.0-8y8reKCbiS2tOAI0cJjk5
key:                  hls-gadt-plugin-2.1.0.0-8y8reKCbiS2tOAI0cJjk5
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  028b360e1de43db97f6da58e8cff5a7a
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.1.0.0-8y8reKCbiS2tOAI0cJjk5
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb base-4.17.2.1 containers-0.6.7
    extra-1.7.16-5K8PvZO4Jh1LEHVlaJYF8M ghc-9.4.8 ghc-boot-th-9.4.8
    ghc-exactprint-1.6.1-KoxfBAoehN54yCB9l1b1I2
    ghcide-2.1.0.0-AgggvO0GGCw1zyuRFufAMJ
    hls-plugin-api-2.1.0.0-69rcYMWo2rGHkR4nX3fnnJ
    hls-refactor-plugin-2.1.0.0-HKOS8bG6AHFYHdJHHfqXC
    lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
